@@ -28,7 +28,7 @@ my $DELIMITER = chr 0x2D;
 my %ENTITIES;
 {
   open my $entities, '<', catfile(dirname(__FILE__), 'entities.txt');
-  $_ =~ /^(\S+)\s+U\+(\S+)/ and $ENTITIES{$1} = chr hex($2) for <$entities>;
+  /^(\S+)\s+U\+(\S+)/ and $ENTITIES{$1} = chr hex($2) for <$entities>;
 }
 
 # Reverse entities for html_escape (without "apos")
@@ -141,7 +141,7 @@ sub html_escape {
 sub html_unescape {
   my $string = shift;
   $string
-    =~ s/&(?:\#((?:\d{1,7}|x[0-9A-Fa-f]{1,6}));|([\w\.]+;?))/_decode($1,$2)/ge;
+    =~ s/&(?:\#((?:\d{1,7}|x[0-9A-Fa-f]{1,6}));|(\w+;?))/_decode($1, $2)/ge;
   return $string;
 }
 
@@ -394,7 +394,6 @@ sub _hmac {
 }
 
 1;
-__END__
 
 =head1 NAME
 
