@@ -14,6 +14,7 @@ use Mojolicious::Types;
 use Scalar::Util qw/blessed weaken/;
 
 # "Robots don't have any emotions, and sometimes that makes me very sad."
+has commands => sub { Mojolicious::Commands->new };
 has controller_class => 'Mojolicious::Controller';
 has mode => sub { ($ENV{MOJO_MODE} || 'development') };
 has plugins  => sub { Mojolicious::Plugins->new };
@@ -33,7 +34,7 @@ has static   => sub { Mojolicious::Static->new };
 has types    => sub { Mojolicious::Types->new };
 
 our $CODENAME = 'Leaf Fluttering In Wind';
-our $VERSION  = '2.91';
+our $VERSION  = '2.92';
 
 # "These old doomsday devices are dangerously unstable.
 #  I'll rest easier not knowing where they are."
@@ -204,16 +205,15 @@ sub start {
   $ENV{MOJO_EXE} ||= (caller)[1];
 
   # We are the application
-  $ENV{MOJO_APP} = ref $class ? $class : $class->new;
+  my $self = $ENV{MOJO_APP} = ref $class ? $class : $class->new;
 
   # Start!
-  Mojolicious::Commands->start(@_);
+  $self->commands->start(@_);
 }
 
 sub startup { }
 
 1;
-__END__
 
 =head1 NAME
 
@@ -250,6 +250,17 @@ Take a look at our excellent documentation in L<Mojolicious::Guides>!
 L<Mojolicious> inherits all attributes from L<Mojo> and implements the
 following new ones.
 
+=head2 C<commands>
+
+  my $commands = $app->commands;
+  $app         = $app->commands(Mojolicious::Commands->new);
+
+Command line interface for your application, defaults to a
+L<Mojolicious::Commands> object.
+
+  # Add another namespace to load commands from
+  push @{$app->commands->namespaces}, 'MyApp::Command';
+
 =head2 C<controller_class>
 
   my $class = $app->controller_class;
@@ -291,6 +302,9 @@ The plugin loader, defaults to a L<Mojolicious::Plugins> object. You can
 usually leave this alone, see L<Mojolicious::Plugin> if you want to write a
 plugin or the C<plugin> method below if you want to load a plugin.
 
+  # Add another namespace to load plugins from
+  push @{$app->plugins->namespaces}, 'MyApp::Plugin';
+
 =head2 C<renderer>
 
   my $renderer = $app->renderer;
@@ -302,7 +316,7 @@ L<Mojolicious::Plugin::EPRenderer> and L<Mojolicious::Plugin::EPLRenderer>
 contain more information.
 
   # Add another "templates" directory
-  push @{$app->renderer->paths}, '/foo/bar/templates';
+  push @{$app->renderer->paths}, '/home/sri/templates';
 
   # Add another class with templates in DATA section
   push @{$app->renderer->classes}, 'Mojolicious::Plugin::Fun';
@@ -351,7 +365,7 @@ For serving static files from your C<public> directories, defaults to a
 L<Mojolicious::Static> object.
 
   # Add another "public" directory
-  push @{$app->static->paths}, '/foo/bar/public';
+  push @{$app->static->paths}, '/home/sri/public';
 
   # Add another class with static files in DATA section
   push @{$app->static->classes}, 'Mojolicious::Plugin::Fun';
